@@ -22,7 +22,7 @@
 
 /* path to resource files */
 #define RES_PATH "/home/opt/mancala/data"
-#define FONT_PATH "/usr/share/fonts/"
+#define FONT_PATH "/home/opt/mancala/data"
 
 /* various constants */
 #define STRING_MAX 1000
